@@ -1,13 +1,25 @@
 import os
 from .utils import transformers
 
+# settings for realtime flag
+S3_REALTIME_BASE = os.environ.get("S3_REALTIME_BASE")  # e.g 's3://realtime-bucket'
+SQS_QUEUE_URL = os.environ.get(
+    "SQS_QUEUE_URL"
+)
+
 # scrape settings
 
 SCRAPELIB_RPM = 60
 SCRAPELIB_TIMEOUT = 60
 SCRAPELIB_RETRY_ATTEMPTS = 3
 SCRAPELIB_RETRY_WAIT_SECONDS = 10
-SCRAPELIB_VERIFY = True
+try:
+    verify = os.environ.get("VERIFY_CERTS", False)
+    if verify == "False":
+        verify = False
+except Exception:
+    verify = False
+SCRAPELIB_VERIFY = verify
 
 CACHE_DIR = os.path.join(os.getcwd(), "_cache")
 SCRAPED_DATA_DIR = os.path.join(os.getcwd(), "_data")
